import type { ComponentLogger, Libp2pEvents, TypedEventTarget, PeerId, PeerStore } from '@libp2p/interface';
import type { AddressManager as AddressManagerInterface, TransportManager } from '@libp2p/interface-internal';
import type { Multiaddr } from '@multiformats/multiaddr';
export interface AddressManagerInit {
    /**
     * Pass an function in this field to override the list of addresses
     * that are announced to the network
     */
    announceFilter?: AddressFilter;
    /**
     * A list of string multiaddrs to listen on
     */
    listen?: string[];
    /**
     * A list of string multiaddrs to use instead of those reported by transports
     */
    announce?: string[];
    /**
     * A list of string multiaddrs string to never announce
     */
    noAnnounce?: string[];
    /**
     * A list of string multiaddrs to add to the list of announced addresses
     */
    appendAnnounce?: string[];
}
export interface AddressManagerComponents {
    peerId: PeerId;
    transportManager: TransportManager;
    peerStore: PeerStore;
    events: TypedEventTarget<Libp2pEvents>;
    logger: ComponentLogger;
}
/**
 * A function that takes a list of multiaddrs and returns a list
 * to announce
 */
export interface AddressFilter {
    (addrs: Multiaddr[]): Multiaddr[];
}
export declare class AddressManager implements AddressManagerInterface {
    private readonly log;
    private readonly components;
    private readonly listen;
    private readonly announce;
    private readonly appendAnnounce;
    private readonly observed;
    private readonly announceFilter;
    private readonly ipDomainMappings;
    /**
     * Responsible for managing the peer addresses.
     * Peers can specify their listen and announce addresses.
     * The listen addresses will be used by the libp2p transports to listen for new connections,
     * while the announce addresses will be used for the peer addresses' to other peers in the network.
     */
    constructor(components: AddressManagerComponents, init?: AddressManagerInit);
    readonly [Symbol.toStringTag] = "@libp2p/address-manager";
    _updatePeerStoreAddresses(): void;
    /**
     * Get peer listen multiaddrs
     */
    getListenAddrs(): Multiaddr[];
    /**
     * Get peer announcing multiaddrs
     */
    getAnnounceAddrs(): Multiaddr[];
    /**
     * Get peer announcing multiaddrs
     */
    getAppendAnnounceAddrs(): Multiaddr[];
    /**
     * Get observed multiaddrs
     */
    getObservedAddrs(): Multiaddr[];
    /**
     * Add peer observed addresses
     */
    addObservedAddr(addr: Multiaddr): void;
    confirmObservedAddr(addr: Multiaddr): void;
    removeObservedAddr(addr: Multiaddr): void;
    getAddresses(): Multiaddr[];
    addDNSMapping(domain: string, addresses: string[]): void;
    removeDNSMapping(domain: string): void;
}
//# sourceMappingURL=address-manager.d.ts.map